@@ -15,10 +15,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "punycode.h"
 
 #include "gettext.h"
